# frozen_string_literal: true

module Github
  def labels
    @github_labels ||=
      github.api.labels(repo_name)
  end

  def repo_name
    github.pr_json['base']['repo']['full_name']
  end

  def pr_number
    github.pr_json['number']
  end

  def add_labels(*new_labels)
    existing = labels.map(&:name)
    new_labels.reject { |l| existing.include?(l) }.each do |to_create|
      github.api.add_label(repo_name, to_create)
    end
    github.api.add_labels_to_an_issue(repo_name, pr_number, new_labels)
  end
end
